@@ -24,7 +24,7 @@ import os
 import time
 
 from manila import exception
-from manila.i18n import _, _LE, _LW
+from manila.i18n import _
 from manila import utils as mutils
 
 LOG = log.getLogger(__name__)
@@ -98,8 +98,8 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'does not exist' in e.stderr:
-                LOG.warning(_LW("Export %s does not exist on "
-                                "backend anymore."), name)
+                LOG.warning("Export %s does not exist on "
+                            "backend anymore.", name)
             else:
                 msg = _("Could not delete NFS export %s.") % name
                 LOG.exception(msg)
@@ -128,8 +128,8 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if e.exit_code == 1:
-                LOG.warning(_LW("CIFS share %s does not exist on "
-                                "backend anymore."), name)
+                LOG.warning("CIFS share %s does not exist on "
+                            "backend anymore.", name)
             else:
                 msg = _("Could not delete CIFS share %s.") % name
                 LOG.exception(msg)
@@ -232,18 +232,18 @@ class HNASSSHBackend(object):
         except processutils.ProcessExecutionError as e:
             if ('not listed as a user' in e.stderr or
                     'Could not delete user/group' in e.stderr):
-                LOG.warning(_LW('User %(user)s already not allowed to access '
-                                '%(entity_type)s %(name)s.'), {
-                                    'entity_type': entity_type,
-                                    'user': user,
-                                    'name': name
-                    })
+                LOG.warning('User %(user)s already not allowed to access '
+                            '%(entity_type)s %(name)s.', {
+                                'entity_type': entity_type,
+                                'user': user,
+                                'name': name
+                            })
             else:
                 msg = _("Could not delete access of user %(user)s to "
                         "%(entity_type)s %(name)s.") % {
-                            'user': user,
-                            'name': name,
-                            'entity_type': entity_type,
+                    'user': user,
+                    'name': name,
+                    'entity_type': entity_type,
                     }
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
@@ -312,8 +312,8 @@ class HNASSSHBackend(object):
                     if now > deadline:
                         command = ['tree-clone-job-abort', job_id]
                         self._execute(command)
-                        LOG.error(_LE("Timeout in snapshot creation from "
-                                      "source path %s.") % src_path)
+                        LOG.error("Timeout in snapshot creation from "
+                                  "source path %s.", src_path)
                         msg = _("Share snapshot of source path %s "
                                 "was not created.") % src_path
                         raise exception.HNASBackendException(msg=msg)
@@ -332,7 +332,7 @@ class HNASSSHBackend(object):
                           {'src': src_path,
                            'dest': dest_path})
             else:
-                LOG.error(_LE('Error creating snapshot of source path %s.'),
+                LOG.error('Error creating snapshot of source path %s.',
                           src_path)
                 msg = _('Snapshot of source path %s was not '
                         'created.') % src_path
@@ -345,23 +345,47 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'Source path: Cannot access' in e.stderr:
-                LOG.warning(_LW("Attempted to delete path %s "
-                                "but it does not exist."), path)
+                LOG.warning("Attempted to delete path %s "
+                            "but it does not exist.", path)
             else:
                 msg = _("Could not submit tree delete job to delete path "
                         "%s.") % path
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
 
+    @mutils.retry(exception=exception.HNASSSCContextChange, wait_random=True,
+                  retries=5)
     def create_directory(self, dest_path):
         self._locked_selectfs('create', dest_path)
+        if not self.check_directory(dest_path):
+            msg = _("Command to create directory %(path)s was run in another "
+                    "filesystem instead of %(fs)s.") % {
+                'path': dest_path,
+                'fs': self.fs_name,
+            }
+            LOG.warning(msg)
+            raise exception.HNASSSCContextChange(msg=msg)
 
+    @mutils.retry(exception=exception.HNASSSCContextChange, wait_random=True,
+                  retries=5)
     def delete_directory(self, path):
-        self._locked_selectfs('delete', path)
+        try:
+            self._locked_selectfs('delete', path)
+        except exception.HNASDirectoryNotEmpty:
+            pass
+        else:
+            if self.check_directory(path):
+                msg = _("Command to delete empty directory %(path)s was run in"
+                        " another filesystem instead of %(fs)s.") % {
+                            'path': path,
+                            'fs': self.fs_name,
+                    }
+                LOG.debug(msg)
+                raise exception.HNASSSCContextChange(msg=msg)
 
     @mutils.retry(exception=exception.HNASSSCIsBusy, wait_random=True,
                   retries=5)
-    def check_snapshot(self, path):
+    def check_directory(self, path):
         command = ['path-to-object-number', '-f', self.fs_name, path]
 
         try:
@@ -425,7 +449,7 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'Source path: Cannot access' in e.stderr:
-                LOG.warning(_LW("Share %s does not exist."), vvol_name)
+                LOG.warning("Share %s does not exist.", vvol_name)
             else:
                 msg = _("Failed to delete vvol %s.") % vvol_name
                 LOG.exception(msg)
@@ -652,10 +676,16 @@ class HNASSSHBackend(object):
                        self.evs_id, 'mkdir', '-p', path]
             try:
                 self._execute(command)
-            except processutils.ProcessExecutionError:
-                msg = _("Failed to create directory %s.") % path
-                LOG.exception(msg)
-                raise exception.HNASBackendException(msg=msg)
+            except processutils.ProcessExecutionError as e:
+                if "Current file system invalid: VolumeNotFound" in e.stderr:
+                    msg = _("Command to create directory %s failed due to "
+                            "context change.") % path
+                    LOG.debug(msg)
+                    raise exception.HNASSSCContextChange(msg=msg)
+                else:
+                    msg = _("Failed to create directory %s.") % path
+                    LOG.exception(msg)
+                    raise exception.HNASBackendException(msg=msg)
 
         if op == 'delete':
             command = ['selectfs', self.fs_name, '\n',
@@ -665,11 +695,17 @@ class HNASSSHBackend(object):
                 self._execute(command)
             except processutils.ProcessExecutionError as e:
                 if 'DirectoryNotEmpty' in e.stderr:
-                    LOG.debug("Share %(path)s has more snapshots.",
-                              {'path': path})
-                elif 'NotFound' in e.stderr:
-                    LOG.warning(_LW("Attempted to delete path %s but it does "
-                                    "not exist."), path)
+                    msg = _("Share %s has more snapshots.") % path
+                    LOG.debug(msg)
+                    raise exception.HNASDirectoryNotEmpty(msg=msg)
+                elif 'cannot remove' in e.stderr and 'NotFound' in e.stderr:
+                    LOG.warning("Attempted to delete path %s but it does "
+                                "not exist.", path)
+                elif 'Current file system invalid: VolumeNotFound' in e.stderr:
+                    msg = _("Command to delete empty directory %s failed due "
+                            "to context change.") % path
+                    LOG.debug(msg)
+                    raise exception.HNASSSCContextChange(msg=msg)
                 else:
                     msg = _("Failed to delete directory %s.") % path
                     LOG.exception(msg)
